# CMake options for configuring the library

## Options

There are the following variables available to configure it:

* `FOONATHAN_MEMORY_DEFAULT_ALLOCATOR`: The default allocator used by the higher level allocator classes. Either `heap_allocator` or `new_allocator`. Default is `heap_allocator`.
* `FOONATHAN_MEMORY_THREAD_SAFE_REFERENCE`: Whether or not the `allocator_reference` is thread safe by default. Default is `ON`.
* `FOONATHAN_MEMORY_DEBUG_*`: specifies debugging options such as pointer check in `deallocate()` or filling newly allocated memory with values. All of them are enabled in `Debug` builds by default, the faster ones in `RelWithDebInfo` and none in `Release`. See [debugging](md_doc_debug_error.html#debugging) for a detailed description.

* `FOONATHAN_HAS_*`: specifies compatibility options, that is, whether a certain C++ feature is available under your compiler. They are automatically detected by CMake, so there is usually no need to change them.
* `FOONATHAN_MEMORY_BUILD_*`: whether or not to build examples or tests. If this is `OFF` their CMake scripts are not even included. It is `ON` for standalone builds and `OFF` if used in `add_subdirectory()`.
* `FOONATHAN_MEMORY_BUILD_TOOLS`: whether or not build the tools. Unlike the other two options, this is always `ON`.
* `FOONATHAN_MEMORY_NAMESPACE_PREFIX`: If `ON`, everything is in namespace `foonathan::memory`. If `OFF`, you can use namespace `memory` directly (the default).
* `FOONATHAN_MEMORY_INCLUDE_PREFIX`: Similar to the namespace prefix, if `ON`, include directory is `<foonathan/memory/*>`, if `OFF`include directory is `<memory/*>` directly (the default).

A list of all options with description is generated by calling `cmake -LH`.

## Variables and targets

The following variables or targets are available if used with `add_subdirectory()`:

* `FOONATHAN_MEMORY_INCLUDE_DIR` (variable): The include directory for the header files.
* `FOONATHAN_MEMORY_VERSION_MAJOR/MINOR` (variable): Major and minor version of the library.
* `foonathan_memory` (target): The target of the library you can link to.
* `foonathan_memory_example_*` (target): The targets for the examples. Only available if `FOONATHAN_MEMORY_BUILD_EXAMPLES` is `ON`.
* `foonathan_memory_test` (target): The test target. Only available if `FOONATHAN_MEMORY_BUILD_TESTS` is `ON`.
* `foonathan_memory_profiling` (target): The profiling target. Only available if `FOONATHAN_MEMORY_BUILD_TESTS` is `ON`.
* `foonathan_memory_node_size_debugger` (target): The target that generates the container node size information. Only available if `FOONATHAN_MEMORY_BUILD_TOOLS` is `ON`.

Also every function from [foonathan/compatibility] is exposed.

[foonathan/compatibility]: https://github.com/foonathan/compatiblity
